@@ -2,11 +2,11 @@
 #######################################################################
 """The object2psadapter class.
 
-$Id: object2psadapter.py 49320 2008-01-09 20:05:51Z cray $
+$Id: object2psadapter.py 49600 2008-01-21 11:08:39Z cray $
 """
 __author__  = "Ischenko Valera, 2006"
 __license__ = "GPL"
-__version__ = "$Revision: 49320 $"
+__version__ = "$Revision: 49600 $"
 
 from zope.interface import implements
 from interfaces import IPropertySheet, IAttributeConvertable
@@ -40,64 +40,45 @@ class Object2PSadapterBase(object):
         return cmp(nx,ny)
         
     def __init__(self, ob):
-        print "1001"
         self.attrdict = {}
         successCached = False
         cached = {}
-        print "1001-2"
         for (name,cache) in zapi.getUtilitiesFor(ICachestore, ob) :
-            print "1001-3",name,cache
             for cache in cache.getCached(ob) :
-                print "1001-4",cache
                 cached[(cache.attribute,cache.converter)] = cache 
-        print "1002"
 
         dictinterfaces = {}
         for (mon,mo) in zapi.getUtilitiesFor(IMapperObject, ob) :
             dictinterfaces.update( mo.lookup(ob) )
          
-        print "1003"
         dictitems = dictinterfaces.items() 
         dictitems.sort(self.cmp)
-        print "1013"
         for iface_in, iface_outd in dictitems :
-            print "1014"
             mapattrd = iface_outd[interface.interfaceToName(self, IPropertySheet)]
-            print "1015"
             
             for attr, desc in mapattrd.items() :
-                print "1016"
                 
                 try :
                     self.attrdict[attr] = cached[(desc.attr,desc.converter)].value
-                    print "1018"
                     
                 except KeyError :
-                    print "1017",desc.converter,desc.attr
                     self.attrdict[attr] = value = \
                         zapi.getSiteManager(ob) \
                             .getUtility(IConverter, desc.converter) \
                             .convert(getattr(ob, desc.attr))                
-                    print "1022"                            
                     csi = CachestoreItem(
                         attribute=desc.attr,
                         converter=desc.converter,
                         value=value,
                         mtime=time.time())
-                    print "1023"                        
                     cached[(desc.attr,desc.converter)] = csi
-                print "1019"
                                     
         li = CacheStoreItemList()
-        print "1020"
         for value in cached.values() :
-            print "1021"
             li.append(value)
-        print "1004"
 
         for (name,cache) in zapi.getUtilitiesFor(ICachestore, ob) :
             cache.save_list(ob,li) 
-        print "1005"
         
 class Object2PSadapter(Object2PSadapterBase):
     """ """
